@@ -9,6 +9,7 @@ from starkware.starknet.core.os.contract_address.contract_address import (
 
 from nile import accounts, deployments
 from nile.common import (
+    NILE_ARTIFACTS_PATH,
     QUERY_VERSION,
     TRANSACTION_VERSION,
     UNIVERSAL_DEPLOYER_ADDRESS,
@@ -96,7 +97,7 @@ class Account(AsyncObject):
             )
             if output is not None:
                 address, index = output
-                self.address = address
+                self.address = normalize_number(address)
                 self.index = index
 
         # we should replace this with static type checks
@@ -106,8 +107,7 @@ class Account(AsyncObject):
     async def deploy(self, salt=None, max_fee=None, query_type=None, watch_mode=None):
         """Deploy an Account contract for the given private key."""
         index = accounts.current_index(self.network)
-        pt = os.path.dirname(os.path.realpath(__file__)).replace("/core", "")
-        overriding_path = (f"{pt}/artifacts", f"{pt}/artifacts/abis")
+        overriding_path = NILE_ARTIFACTS_PATH
 
         class_hash = get_account_class_hash("Account")
         salt = 0 if salt is None else normalize_number(salt)
@@ -137,7 +137,7 @@ class Account(AsyncObject):
         )
 
         if output is not None:
-            address, _ = output
+            address, *_ = output
             accounts.register(
                 self.signer.public_key, address, index, self.alias, self.network
             )
@@ -152,10 +152,15 @@ class Account(AsyncObject):
         overriding_path=None,
         mainnet_token=None,
         watch_mode=None,
+        nile_account=False,
     ):
         """Declare a contract through an Account."""
         max_fee, nonce, _ = await self._process_arguments(max_fee, nonce)
 
+        if nile_account:
+            assert overriding_path is None, "Cannot override path to Nile account."
+            overriding_path = NILE_ARTIFACTS_PATH
+
         contract_class = get_contract_class(
             contract_name=contract_name, overriding_path=overriding_path
         )
@@ -174,6 +179,7 @@ class Account(AsyncObject):
             alias=alias,
             network=self.network,
             max_fee=max_fee,
+            overriding_path=overriding_path,
             mainnet_token=mainnet_token,
             watch_mode=watch_mode,
         )
@@ -187,6 +193,7 @@ class Account(AsyncObject):
         alias,
         max_fee=None,
         deployer_address=None,
+        overriding_path=None,
         abi=None,
         watch_mode=None,
     ):
@@ -195,7 +202,9 @@ class Account(AsyncObject):
             deployer_address or UNIVERSAL_DEPLOYER_ADDRESS
         )
 
-        await deploy_with_deployer(
+        max_fee, _, calldata = await self._process_arguments(max_fee, 0, calldata)
+
+        return await deploy_with_deployer(
             self,
             contract_name,
             salt,
@@ -204,6 +213,7 @@ class Account(AsyncObject):
             alias,
             deployer_address,
             max_fee,
+            overriding_path=overriding_path,
             abi=abi,
             watch_mode=watch_mode,
         )
