@@ -7,7 +7,7 @@ from starkware.starknet.core.os.contract_address.contract_address import (
 )
 from starkware.starknet.services.api.gateway.transaction import DeployAccount
 
-from nile import deployments
+from nile import accounts, deployments
 from nile.common import (
     ABIS_DIRECTORY,
     BUILD_DIRECTORY,
@@ -101,7 +101,7 @@ async def deploy_contract(
         _salt = compute_hash_chain(data=[account.address, salt])
         deployer_for_address_generation = deployer_address
 
-    class_hash = get_class_hash(contract_name=contract_name)
+    class_hash = get_class_hash(contract_name, overriding_path)
 
     address = calculate_contract_address_from_hash(
         _salt, class_hash, calldata, deployer_for_address_generation
@@ -128,7 +128,7 @@ async def deploy_contract(
             deployments.unregister(address, account.network, alias, abi=register_abi)
             return
 
-    return address, register_abi
+    return address, tx_hash, register_abi
 
 
 async def deploy_account(
@@ -182,6 +182,7 @@ async def deploy_account(
         tx_status = await status(tx_hash, network, watch_mode)
         if tx_status.status.is_rejected:
             deployments.unregister(address, network, alias, abi=register_abi)
+            accounts.unregister(address, network)
             return
 
-    return address, register_abi
+    return address, tx_hash, register_abi
