@@ -1,25 +1,21 @@
 """Command to start StarkNet local network."""
-import json
 import logging
 import subprocess
 
-from nile.common import NODE_FILENAME
+from nile.common import DEFAULT_GATEWAYS, write_node_json
 
 
 def node(host="127.0.0.1", port=5050, seed=None, lite_mode=False):
     """Start StarkNet local network."""
     try:
         # Save host and port information to be used by other commands
-        file = NODE_FILENAME
         if host == "127.0.0.1":
             network = "localhost"
         else:
             network = host
         gateway_url = f"http://{host}:{port}/"
-        gateway = {network: gateway_url}
-
-        with open(file, "w+") as f:
-            json.dump(gateway, f)
+        if DEFAULT_GATEWAYS.get(network) != gateway_url:
+            write_node_json(network, gateway_url)
 
         command = ["starknet-devnet", "--host", host, "--port", str(port)]
 
