@@ -4,7 +4,12 @@ from unittest.mock import patch
 
 import pytest
 
-from nile.common import ACCOUNTS_FILENAME, BUILD_DIRECTORY, DEPLOYMENTS_FILENAME
+from nile.common import (
+    ACCOUNTS_FILENAME,
+    BUILD_DIRECTORY,
+    DECLARATIONS_FILENAME,
+    DEPLOYMENTS_FILENAME,
+)
 from nile.core.clean import clean
 
 
@@ -27,6 +32,7 @@ def test_clean_already_clean(mock_os_remove, mock_shutil_rmtree):
     [
         f"localhost.{ACCOUNTS_FILENAME}",
         f"localhost.{DEPLOYMENTS_FILENAME}",
+        f"localhost.{DECLARATIONS_FILENAME}",
     ],
 )
 @patch("nile.core.clean.shutil.rmtree")
