@@ -15,16 +15,20 @@ from nile.utils.get_accounts import (
 )
 from tests.mocks.mock_response import MockResponse
 
-NETWORK = "goerli"
+NETWORK = "localhost"
 GATEWAYS = {"localhost": "http://127.0.0.1:5050/"}
 PUBKEYS = [
     883045738439352841478194533192765345509759306772397516907181243450667673002,
     661519931401775515888740911132355225260405929679788917190706536765421826262,
 ]
-ADDRESSES = ["333", "444"]
+ADDRESSES = [333, 333]
 INDEXES = [0, 1]
 ALIASES = ["TEST_KEY", "TEST_KEY_2"]
 
+
+MOCK_ADDRESS = 0x123
+MOCK_INDEX = 0
+
 MOCK_ACCOUNTS = {
     PUBKEYS[0]: {
         "address": ADDRESSES[0],
@@ -57,12 +61,7 @@ def tmp_working_dir(monkeypatch, tmp_path):
     return tmp_path
 
 
-@pytest.fixture(autouse=True)
-def mock_subprocess():
-    with patch("nile.core.compile.subprocess") as mock_subprocess:
-        yield mock_subprocess
-
-
+@pytest.mark.asyncio
 @pytest.mark.parametrize(
     "private_keys, public_keys",
     [
@@ -70,13 +69,17 @@ def mock_subprocess():
         ([ALIASES[1], PUBKEYS[1]]),
     ],
 )
-def test__check_and_return_account_with_matching_keys(private_keys, public_keys):
+@patch("nile.core.account.Account.deploy", return_value=(MOCK_ADDRESS, MOCK_INDEX))
+async def test__check_and_return_account_with_matching_keys(
+    mock_deploy, private_keys, public_keys
+):
     # Check matching public/private keys
-    account = _check_and_return_account(private_keys, public_keys, NETWORK)
+    account = await _check_and_return_account(private_keys, public_keys, NETWORK)
 
     assert type(account) is Account
 
 
+@pytest.mark.asyncio
 @pytest.mark.parametrize(
     "private_keys, public_keys",
     [
@@ -84,16 +87,21 @@ def test__check_and_return_account_with_matching_keys(private_keys, public_keys)
         ([ALIASES[1], PUBKEYS[0]]),
     ],
 )
-def test__check_and_return_account_with_mismatching_keys(private_keys, public_keys):
+@patch("nile.core.account.Account.deploy", return_value=(MOCK_ADDRESS, MOCK_INDEX))
+async def test__check_and_return_account_with_mismatching_keys(
+    mock_deploy, private_keys, public_keys
+):
     # Check mismatched public/private keys
     with pytest.raises(AssertionError) as err:
-        _check_and_return_account(private_keys, public_keys, NETWORK)
+        await _check_and_return_account(private_keys, public_keys, NETWORK)
 
     assert "Signer pubkey does not match deployed pubkey" in str(err.value)
 
 
-def test_get_accounts_no_activated_accounts_feedback(capsys):
-    get_accounts(NETWORK)
+@pytest.mark.asyncio
+@patch("nile.core.account.Account.deploy", return_value=(MOCK_ADDRESS, MOCK_INDEX))
+async def test_get_accounts_no_activated_accounts_feedback(mock_deploy, capsys):
+    await get_accounts(NETWORK)
     # This test uses capsys in order to test the print statements (instead of logging)
     captured = capsys.readouterr()
 
@@ -106,14 +114,16 @@ def test_get_accounts_no_activated_accounts_feedback(capsys):
     )
 
 
+@pytest.mark.asyncio
+@patch("nile.core.account.Account.deploy", return_value=(MOCK_ADDRESS, MOCK_INDEX))
 @patch("nile.utils.get_accounts.current_index", MagicMock(return_value=len(PUBKEYS)))
 @patch("nile.utils.get_accounts.open", MagicMock())
 @patch("nile.utils.get_accounts.json.load", MagicMock(return_value=MOCK_ACCOUNTS))
-def test_get_accounts_activated_accounts_feedback(caplog):
+async def test_get_accounts_activated_accounts_feedback(mock_deploy, caplog):
     logging.getLogger().setLevel(logging.INFO)
 
     # Default argument
-    get_accounts(NETWORK)
+    await get_accounts(NETWORK)
 
     # Check total accounts log
     assert f"\nTotal registered accounts: {len(PUBKEYS)}\n" in caplog.text
@@ -126,15 +136,16 @@ def test_get_accounts_activated_accounts_feedback(caplog):
     assert "\n🚀 Successfully retrieved deployed accounts" in caplog.text
 
 
+@pytest.mark.asyncio
+@patch("nile.core.account.Account.deploy", return_value=(MOCK_ADDRESS, MOCK_INDEX))
 @patch("nile.utils.get_accounts.current_index", MagicMock(return_value=len(PUBKEYS)))
 @patch("nile.utils.get_accounts.open", MagicMock())
 @patch("nile.utils.get_accounts.json.load", MagicMock(return_value=MOCK_ACCOUNTS))
-def test_get_accounts_with_keys():
-
+async def test_get_accounts_with_keys(mock_deploy):
     with patch(
         "nile.utils.get_accounts._check_and_return_account"
     ) as mock_return_account:
-        result = get_accounts(NETWORK)
+        result = await get_accounts(NETWORK)
 
         # Check correct args are passed to `_check_and_receive_account`
         for i in range(len(PUBKEYS)):
@@ -147,11 +158,14 @@ def test_get_accounts_with_keys():
         assert len(result) == len(PUBKEYS)
 
 
-@patch("nile.common.get_gateway", return_value=GATEWAYS)
+@pytest.mark.asyncio
+@patch("nile.common.get_gateways", return_value=GATEWAYS)
 @patch("nile.utils.get_accounts._check_and_return_account")
 @patch("requests.get", return_value=MockResponse(JSON_DATA, 200))
-def test_get_predeployed_accounts(mock_response, mock_return_account, mock_gateways):
-    result = get_predeployed_accounts("localhost")
+async def test_get_predeployed_accounts(
+    mock_response, mock_return_account, mock_gateways
+):
+    result = await get_predeployed_accounts("localhost")
 
     # Assert the correct endpoint is used
     mock_response.assert_called_once_with(
@@ -179,17 +193,19 @@ def test_get_predeployed_accounts(mock_response, mock_return_account, mock_gatew
     assert len(result) == len(JSON_DATA)
 
 
-@patch("nile.common.get_gateway", return_value=GATEWAYS)
+@pytest.mark.asyncio
+@patch("nile.core.account.Account.deploy", return_value=(MOCK_ADDRESS, MOCK_INDEX))
+@patch("nile.common.get_gateways", return_value=GATEWAYS)
 @patch("nile.utils.get_accounts._check_and_return_account")
 @patch("requests.get", return_value=MockResponse(JSON_DATA, 200))
-def test_get_predeployed_accounts_logging(
-    mock_response, mock_return_account, mock_gateways, caplog
+async def test_get_predeployed_accounts_logging(
+    mock_response, mock_return_account, mock_gateways, mock_deploy, caplog
 ):
     # make logs visible to test
     logger = logging.getLogger()
 
     logger.setLevel(logging.INFO)
-    get_predeployed_accounts("localhost")
+    await get_predeployed_accounts("localhost")
 
     assert "🚀 Successfully retrieved pre-deployed accounts" in caplog.text
 
@@ -198,13 +214,13 @@ def test_get_predeployed_accounts_logging(
 
     # test missing schema first
     mock_response.side_effect = MissingSchema
-    get_predeployed_accounts("localhost")
+    await get_predeployed_accounts("localhost")
 
     assert "❌ Failed to retrieve gateway from provided network" in caplog.text
 
     # test generic exceptions
     mock_response.side_effect = Exception
-    get_predeployed_accounts("localhost")
+    await get_predeployed_accounts("localhost")
 
     assert "❌ Error querying the account from the gateway" in caplog.text
     assert "Check you are connected to a starknet-devnet implementation" in caplog.text
